@@ -52,7 +52,6 @@ describe 'openstack_extras::repo::redhat::redhat' do
       it { is_expected.to contain_yumrepo('rdo-release').with(
         :baseurl    => "http://mirror.centos.org/centos/7/cloud/$basearch/openstack-newton/",
         :descr      => "OpenStack Newton Repository",
-        :priority   => 98,
         :gpgkey     => "file:///etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-Cloud",
         :enabled    => '1',
         :gpgcheck   => '1',
@@ -61,6 +60,17 @@ describe 'openstack_extras::repo::redhat::redhat' do
         :notify     => "Exec[yum_refresh]"
       )}
 
+      it { is_expected.to contain_yumrepo('rdo-qemu-ev').with(
+        :baseurl    => "http://mirror.centos.org/centos/7/virt/$basearch/kvm-common/",
+        :descr      => "RDO CentOS-7 - QEMU EV",
+        :gpgkey     => "file:///etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-Virtualization",
+        :enabled    => '1',
+        :gpgcheck   => '1',
+        :mirrorlist => 'absent',
+        :require    => "Anchor[openstack_extras_redhat]",
+        :notify     => "Exec[yum_refresh]"
+      )}
+
       it { is_expected.to contain_exec('installing_yum-plugin-priorities').with(
         :command   => '/usr/bin/yum install -y yum-plugin-priorities',
         :logoutput => 'on_failure',
@@ -104,6 +114,14 @@ describe 'openstack_extras::repo::redhat::redhat' do
         :before     => "Anchor[openstack_extras_redhat]"
       )}
 
+      it { is_expected.to contain_file('/etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-Virtualization').with(
+        :source     => "puppet:///modules/openstack_extras/RPM-GPG-KEY-CentOS-SIG-Virtualization",
+        :owner      => 'root',
+        :group      => 'root',
+        :mode       => '0644',
+        :before     => "Anchor[openstack_extras_redhat]"
+      )}
+
     end
 
     describe 'with overridden release' do
@@ -208,6 +226,15 @@ describe 'openstack_extras::repo::redhat::redhat' do
 
       it { is_expected.to_not contain_yumrepo('rdo-release') }
     end
+
+    describe 'with rdo-virt management disabled' do
+      let :params do
+        default_params.merge!({ :manage_virt => false })
+      end
+
+      it { is_expected.to_not contain_yumrepo('rdo-qemu-ev') }
+    end
+
     describe 'with manage_priorities disabled' do
       let :params do
         default_params.merge!({ :manage_priorities => false })
